@@ -3,8 +3,8 @@ from typing import List, Union
 from ncbi.datasets.openapi.models import V1AssemblyMatch
 from ncbi.datasets.openapi.models import V1AssemblyDatasetDescriptor
 from ncbi.datasets.openapi import ApiClient as DatasetsApiClient
-from ncbi.datasets.openapi import GenomeApi as DatasetsGenomeApi
 from ncbi.datasets.openapi import ApiException as DatasetsApiException
+from ncbi.datasets.openapi.api.genome_api import GenomeApi as DatasetsGenomeApi
 
 PAGE_SIZE_MAX = 1000
 
